#
# spec file for package python-typed-ast
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define skip_python2 1
Name:           python-typed-ast
Version:        1.3.1
Release:        lp151.2.6.1
Summary:        A fork of Python 2 and 3 ast modules with type comment support
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/python/typed_ast
# not available at usual download URL (anymore?)
Source0:        https://files.pythonhosted.org/packages/fc/c6/61d6410fc70fda073bd1810f9b7f7022f00146b108f278a0c00041bfe5b0/typed-ast-1.3.1.tar.gz
# PATCH-FIX-UPSTREAM fix-out-of-bounds-array-reads.patch bnc#1161562 boo#1161563
Patch0:         https://github.com/python/typed_ast/commit/dc317ac9cff859aa84eeabe03fb5004982545b3b.patch#/fix-out-of-bounds-array-reads.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%python_subpackages

%description
typed_ast is a Python 3 package that provides a Python 2.7 and Python 3
parser similar to the standard ast library. Unlike ast, the parsers in
typed_ast include PEP 484 type comments and are independent of the version of
Python under which they are run. The typed_ast parsers produce the standard
Python AST (plus type comments), and are both fast and correct, as they are
based on the CPython 2.7 and 3.6 parsers.

%prep
%setup -q -n typed-ast-%{version}
%patch0 -p1

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%files %{python_files}
%license LICENSE
%doc README.md
%{python_sitearch}/*

%changelog
* Sun Feb 23 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- Revert to version 1.3.1 as versions >= 1.4.0 breaks mypy, fixes boo#1163532.
- Add fix-out-of-bounds-array-reads.patch to fix boo#1161562 and boo#1161563 / CVE-2019-19274 and CVE-2019-19275
* Sat Feb  1 2020 Sebastian Wagner <sebix+novell.com@sebix.at>
- update to version 1.4.1:
  * Clean up old build scripts (#123)
  * Build artifacts for 3.8 (#127)
  * Fix build on cpython (3.9) master branch (#128)
- version update to 1.4.0
  * Fix compilation on Python 3.8
- Do not use the %%pytest_arch call but expand it as the tests
  seem to need more verbosity otherwise they fail sometimes
  (fishy, but works)
- Use %%pytest_arch
- Add missing fdupes call
- version update to 1.3.5
  * Counteract PyTuple_SetItem stealing reference in _PyObject_FastCall
    fallback (#104)
- run tests
- update to version 1.3.4:
  * Oops: add the pgenheaders files to the depends lists
- update to version 1.3.3:
  * Don't rely on Python's pgenheaders.h (#101)
- update to version 1.3.2:
  * Fix two out-of-bounds array reads (#99)
* Sun Feb 10 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.3.1:
  * Disallow two type comments on one def
  * Fix memory leaks caused by type comment parsing (#91)
  * Fix some broken asserts relating to handling of async keyword (#92)
  * Check NEW_TYPE_COMMENT calls for failure (#93)
- Update to version 1.3.0:
  * Fully incorporate the code from Python 3.7.2
  * Fix some compiler warnings
  * Add a kind field to Bytes as well (#83)
  * Fix await in functions with type comments (#86)
  * Put _ast3 and _ast27 in the typed_ast package (#85)
  * Fix f-string parsing to not think everything is a set (#87)
* Tue Jan 15 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.2.0:
  * Fix conversions.py2to3 on unicode strings (#67)
  * Fix remaining calls to Str without a kind (#68)
  * Add "Python :: 3.7" to the classifiers list
  * Some docs updates (#73)
* Wed Jan  2 2019 Sebastian Wagner <sebix+novell.com@sebix.at>
- Update to version 1.1.1:
  * Add __version__ string and tweak versioning scheme
  * Point to the Python 3.6 commits as examples of how to update typed_ast (
  * Add section on development philosophy
  * Add information about the release process.
  * Document Google Cloud Storage artifact deployment
  * Preserve string kind modifiers
  * Add docs for Str.kind
* Thu Sep 20 2018 Tomáš Chvátal <tchvatal@suse.com>
- Use license macro for license install
* Thu Jul 20 2017 sebix+novell.com@sebix.at
- update to version 1.1.0
  * Vs2010 compilation support (Python 3.3/3.4 support) (#47)
* Tue Jun 27 2017 sebix+novell.com@sebix.at
- use new %%skip_python2 instead of obsolete undefines
* Tue Jun 20 2017 sebix+novell.com@sebix.at
- update to version 1.0.4
  * Add checks for some 3.5+ only syntax (async/await and the @ operator) (#41)
* Wed May 31 2017 sebix+novell.com@sebix.at
- initial package
